aboutsummaryrefslogtreecommitdiff
path: root/src/policy/ephemeral_policy.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/policy/ephemeral_policy.h')
-rw-r--r--src/policy/ephemeral_policy.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/policy/ephemeral_policy.h b/src/policy/ephemeral_policy.h
index 015c0770c1..f9c6e4363e 100644
--- a/src/policy/ephemeral_policy.h
+++ b/src/policy/ephemeral_policy.h
@@ -50,8 +50,9 @@ bool PreCheckEphemeralTx(const CTransaction& tx, CFeeRate dust_relay_rate, CAmou
/** Must be called for each transaction(package) if any dust is in the package.
* Checks that each transaction's parents have their dust spent by the child,
* where parents are either in the mempool or in the package itself.
* @returns std::nullopt if all dust is properly spent, or the txid of the violating child spend.
*/
-std::optional<Txid> CheckEphemeralSpends(const Package& package, CFeeRate dust_relay_rate, const CTxMemPool& tx_pool);
+bool CheckEphemeralSpends(const Package& package, CFeeRate dust_relay_rate, const CTxMemPool& tx_pool, TxValidationState& out_child_state, Txid& out_child_txid);
#endif // BITCOIN_POLICY_EPHEMERAL_POLICY_H
@@ -50,8 +50,9 @@ bool PreCheckEphemeralTx(const CTransaction& tx, CFeeRate dust_relay_rate, CAmou
* Checks that each transaction's parents have their dust spent by the child,
* where parents are either in the mempool or in the package itself.
- * @returns std::nullopt if all dust is properly spent, or the txid of the violating child spend.
+ * Sets out_child_state and out_child_txid on failure.
+ * @returns true if all dust is properly spent.
*/